@@ -181,18 +181,24 @@ class VariableOsAudioCardDefault(Variable):
     Идентификатор карты по умолчанию
     """
     def get(self):
-        cardmap = dict(self.Get("os_audio_card_map"))
-        cardnum = self.Get('os_audio_default').split(',')[0]
-        if cardnum in cardmap:
-            return cardmap[cardnum]
-        return "0"
+        audio_default = self.Get('os_audio_default')
+        if audio_default:
+            cardmap = dict(self.Get("os_audio_card_map"))
+            cardnum = audio_default.split(',')[0]
+            if cardnum in cardmap:
+                return cardmap[cardnum]
+            return "0"
+        return ""
 
 class VariableOsAudioDeviceDefault(Variable):
     """
     Номер устройства по умолчанию
     """
     def get(self):
-        return self.Get('os_audio_default').split(',')[1]
+        audio_default = self.Get('os_audio_default')
+        if audio_default:
+            return self.Get('os_audio_default').split(',')[1]
+        return ""
 
 
 class VariableOsAudioCardNameDefault(Variable):
@@ -207,7 +213,7 @@ class VariableOsAudioCardNameDefault(Variable):
                 return audionames[cardnum].split(',')[0]
         except ValueError:
             pass
-        return "0"
+        return ""
 
 
 class VariableOsAudioHw(Variable):
@@ -260,13 +266,16 @@ class VariableOsAudioDefault(Variable):
             cardid, devicenum = current.split(",")
             if cardid in cardmap:
                 return "{},{}".format(cardmap[cardid], devicenum)
-        return "0,0"
+        data = self.Get('os_audio_data')
+        if data and data[0]:
+            return "0,0"
+        return ""
 
     def choice(self):
         data = self.Get('os_audio_data')
         if data and data[0]:
             return self.Get('os_audio_data')
-        return []
+        return [("", _("Not available"))]
 
     def uncompatible(self):
         """
